"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.reorderCategoryEvents = exports.listEventCategories = exports.bulkUnassignEventsAsync = exports.bulkUnassignEvents = exports.unassignEvents = exports.bulkAssignEventsAsync = exports.bulkAssignEvents = exports.assignEvents = exports.queryCategories = exports.deleteCategory = exports.updateCategory = exports.bulkCreateCategory = exports.createCategory = exports.WebhookIdentityType = exports.CategoryFieldset = exports.SortOrder = exports.State = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const query_builder_1 = require("@wix/sdk-runtime/query-builder");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixEventsV1Category = __importStar(require("./events-v1-category-categories.http.js"));
// @ts-ignore
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
var State;
(function (State) {
    /** Created manually by the user. */
    State["MANUAL"] = "MANUAL";
    /** Created automatically. */
    State["AUTO"] = "AUTO";
    /** Created when publishing recurring events. */
    State["RECURRING_EVENT"] = "RECURRING_EVENT";
    /** Category is hidden. */
    State["HIDDEN"] = "HIDDEN";
})(State || (exports.State = State = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var CategoryFieldset;
(function (CategoryFieldset) {
    /** Include `assignedEventsCount` in the response. */
    CategoryFieldset["COUNTS"] = "COUNTS";
})(CategoryFieldset || (exports.CategoryFieldset = CategoryFieldset = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Creates a category.
 * @public
 * @requiredField category
 * @param category - Category to create.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Created category.
 * @fqn wix.events.categories.CategoryManagement.CreateCategory
 */
async function createCategory(category) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ category: category });
    const reqOpts = ambassadorWixEventsV1Category.createCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.category;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { category: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['category']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createCategory = createCategory;
/**
 * Creates multiple categories at once.
 * @param categories - Categories to create.
 * @public
 * @requiredField categories
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkCreateCategory
 */
async function bulkCreateCategory(categories) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categories: categories,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkCreateCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categories: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['categories']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkCreateCategory = bulkCreateCategory;
/**
 * Updates an existing category.
 * @param _id - Category ID.
 * @public
 * @requiredField _id
 * @requiredField category
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @returns Updated category.
 * @fqn wix.events.categories.CategoryManagement.UpdateCategory
 */
async function updateCategory(_id, category) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        category: { ...category, id: _id },
    });
    const reqOpts = ambassadorWixEventsV1Category.updateCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.category;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: { category: '$[1]' },
            explicitPathsToArguments: { 'category.id': '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'category']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updateCategory = updateCategory;
/**
 * Deletes a category.
 * @param categoryId - ID of category to be deleted.
 * @public
 * @requiredField categoryId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.DeleteCategory
 */
async function deleteCategory(categoryId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
    });
    const reqOpts = ambassadorWixEventsV1Category.deleteCategory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['categoryId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteCategory = deleteCategory;
/**
 * Creates a query to retrieve a list of categories.
 *
 *
 * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
 *
 * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
 *
 * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
 *
 *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
 * @public
 * @param options - Options to use when querying categories.
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.QueryCategories
 */
function queryCategories(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    return (0, query_builder_1.queryBuilder)({
        func: async (payload) => {
            const reqOpts = ambassadorWixEventsV1Category.queryCategories({
                ...payload,
                ...(options ?? {}),
            });
            sideEffects?.onSiteCall?.();
            try {
                const result = await httpClient.request(reqOpts);
                sideEffects?.onSuccess?.(result);
                return result;
            }
            catch (err) {
                sideEffects?.onError?.(err);
                throw err;
            }
        },
        requestTransformer: (query) => {
            const args = [query, options];
            return (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
                ...args?.[1],
                query: args?.[0],
            });
        },
        responseTransformer: ({ data }) => {
            const transformedData = (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(data, []));
            return {
                items: transformedData?.categories,
                pagingMetadata: transformedData?.metaData,
            };
        },
        errorTransformer: (err) => {
            const transformedError = (0, transform_error_1.transformError)(err, {
                spreadPathsToArguments: {},
                explicitPathsToArguments: { query: '$[0]' },
                singleArgumentUnchanged: false,
            });
            throw transformedError;
        },
        pagingMethod: 'OFFSET',
        transformationPaths: {},
    });
}
exports.queryCategories = queryCategories;
/**
 * Assigns events to a single category.
 * @param categoryId - ID of category to which events should be assigned.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.AssignEvents
 */
async function assignEvents(categoryId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.assignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.assignEvents = assignEvents;
/**
 * Assigns events to multiple categories at once.
 * @param categoryId - A list of category IDs to which events should be assigned.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.eventId
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEvents
 */
async function bulkAssignEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        eventId: options?.eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkAssignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkAssignEvents = bulkAssignEvents;
/**
 * Assigns events that match given filter criteria to multiple categories.
 *
 * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category IDs.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when assigning events to multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkAssignEventsAsync
 */
async function bulkAssignEventsAsync(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        filter: options?.filter,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkAssignEventsAsync(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', filter: '$[1].filter' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkAssignEventsAsync = bulkAssignEventsAsync;
/**
 * Unassigns events from a category.
 * @param categoryId - Category ID.
 * @param eventId - A list of events IDs.
 * @public
 * @requiredField categoryId
 * @requiredField eventId
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.UnassignEvents
 */
async function unassignEvents(categoryId, eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        eventId: eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.unassignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', eventId: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.unassignEvents = unassignEvents;
/**
 * Unassigns events from multiple categories at once.
 * @param categoryId - A list of category IDs.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEvents
 */
async function bulkUnassignEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        eventId: options?.eventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkUnassignEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkUnassignEvents = bulkUnassignEvents;
/**
 * Removes events that match given filter criteria from multiple categories.
 *
 * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @requiredField options
 * @requiredField options.filter
 * @param options - Options to use when removing events from multiple categories.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.BulkUnassignEventsAsync
 */
async function bulkUnassignEventsAsync(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        filter: options?.filter,
    });
    const reqOpts = ambassadorWixEventsV1Category.bulkUnassignEventsAsync(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { categoryId: '$[0]', filter: '$[1].filter' },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkUnassignEventsAsync = bulkUnassignEventsAsync;
/**
 * Retrieves a list of categories that are not in the `HIDDEN` state.
 * @param eventId - Event ID.
 * @public
 * @requiredField eventId
 * @permissionId WIX_EVENTS.READ_CATEGORIES
 * @permissionScope Read Events - all read permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.READ-EVENTS
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Read Events
 * @permissionScopeId SCOPE.DC-EVENTS.READ-EVENTS
 * @permissionScope Manage Guest List
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-GUEST-LIST
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.DC-EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.events.categories.CategoryManagement.ListEventCategories
 */
async function listEventCategories(eventId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ eventId: eventId });
    const reqOpts = ambassadorWixEventsV1Category.listEventCategories(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { eventId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['eventId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listEventCategories = listEventCategories;
/**
 * Change the order of events that are assigned to the same category on the Events Widget.
 *
 *
 * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
 * @param categoryId - Category ID.
 * @public
 * @requiredField categoryId
 * @param options - Options to use when reordering events.
 * @permissionId WIX_EVENTS.MANAGE_CATEGORIES
 * @permissionScope Manage Events - all permissions
 * @permissionScopeId SCOPE.DC-EVENTS-MEGA.MANAGE-EVENTS
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @applicableIdentity APP
 * @fqn wix.events.categories.CategoryManagement.ReorderCategoryEvents
 */
async function reorderCategoryEvents(categoryId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        categoryId: categoryId,
        eventId: options?.eventId,
        beforeEventId: options?.beforeEventId,
        afterEventId: options?.afterEventId,
    });
    const reqOpts = ambassadorWixEventsV1Category.reorderCategoryEvents(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                categoryId: '$[0]',
                eventId: '$[1].eventId',
                beforeEventId: '$[1].beforeEventId',
                afterEventId: '$[1].afterEventId',
            },
            singleArgumentUnchanged: false,
        }, ['categoryId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.reorderCategoryEvents = reorderCategoryEvents;
//# sourceMappingURL=events-v1-category-categories.universal.js.map