import { HttpClient } from '@wix/sdk-types';
import { BulkAssignEventsAsyncOptions, BulkAssignEventsOptions, BulkAssignEventsResponse, BulkCreateCategoryResponse, BulkUnassignEventsAsyncOptions, BulkUnassignEventsOptions, BulkUnassignEventsResponse, CategoriesQueryBuilder, Category, ListEventCategoriesResponse, QueryCategoriesOptions, ReorderCategoryEventsOptions, UpdateCategory } from './events-v1-category-categories.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createCategory(httpClient: HttpClient): CreateCategorySignature;
interface CreateCategorySignature {
    /**
     * Creates a category.
     * @param - Category to create.
     * @returns Created category.
     */
    (category: Category): Promise<Category>;
}
export declare function bulkCreateCategory(httpClient: HttpClient): BulkCreateCategorySignature;
interface BulkCreateCategorySignature {
    /**
     * Creates multiple categories at once.
     * @param - Categories to create.
     */
    (categories: Category[]): Promise<BulkCreateCategoryResponse>;
}
export declare function updateCategory(httpClient: HttpClient): UpdateCategorySignature;
interface UpdateCategorySignature {
    /**
     * Updates an existing category.
     * @param - Category ID.
     * @returns Updated category.
     */
    (_id: string, category: UpdateCategory): Promise<Category>;
}
export declare function deleteCategory(httpClient: HttpClient): DeleteCategorySignature;
interface DeleteCategorySignature {
    /**
     * Deletes a category.
     * @param - ID of category to be deleted.
     */
    (categoryId: string): Promise<void>;
}
export declare function queryCategories(httpClient: HttpClient): QueryCategoriesSignature;
interface QueryCategoriesSignature {
    /**
     * Creates a query to retrieve a list of categories.
     *
     *
     * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
     *
     * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
     *
     * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
     *
     * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
     *
     *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
     * @param - Options to use when querying categories.
     */
    (options?: QueryCategoriesOptions | undefined): CategoriesQueryBuilder;
}
export declare function assignEvents(httpClient: HttpClient): AssignEventsSignature;
interface AssignEventsSignature {
    /**
     * Assigns events to a single category.
     * @param - ID of category to which events should be assigned.
     * @param - A list of events IDs.
     */
    (categoryId: string, eventId: string[]): Promise<void>;
}
export declare function bulkAssignEvents(httpClient: HttpClient): BulkAssignEventsSignature;
interface BulkAssignEventsSignature {
    /**
     * Assigns events to multiple categories at once.
     * @param - A list of category IDs to which events should be assigned.
     * @param - Options to use when assigning events to multiple categories.
     */
    (categoryId: string[], options: BulkAssignEventsOptions): Promise<BulkAssignEventsResponse>;
}
export declare function bulkAssignEventsAsync(httpClient: HttpClient): BulkAssignEventsAsyncSignature;
interface BulkAssignEventsAsyncSignature {
    /**
     * Assigns events that match given filter criteria to multiple categories.
     *
     * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
     *
     * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
     * @param - Category IDs.
     * @param - Options to use when assigning events to multiple categories.
     */
    (categoryId: string[], options: BulkAssignEventsAsyncOptions): Promise<void>;
}
export declare function unassignEvents(httpClient: HttpClient): UnassignEventsSignature;
interface UnassignEventsSignature {
    /**
     * Unassigns events from a category.
     * @param - Category ID.
     * @param - A list of events IDs.
     */
    (categoryId: string, eventId: string[]): Promise<void>;
}
export declare function bulkUnassignEvents(httpClient: HttpClient): BulkUnassignEventsSignature;
interface BulkUnassignEventsSignature {
    /**
     * Unassigns events from multiple categories at once.
     * @param - A list of category IDs.
     * @param - Options to use when removing events from multiple categories.
     */
    (categoryId: string[], options?: BulkUnassignEventsOptions | undefined): Promise<BulkUnassignEventsResponse>;
}
export declare function bulkUnassignEventsAsync(httpClient: HttpClient): BulkUnassignEventsAsyncSignature;
interface BulkUnassignEventsAsyncSignature {
    /**
     * Removes events that match given filter criteria from multiple categories.
     *
     * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
     *
     * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
     * @param - Category ID.
     * @param - Options to use when removing events from multiple categories.
     */
    (categoryId: string[], options: BulkUnassignEventsAsyncOptions): Promise<void>;
}
export declare function listEventCategories(httpClient: HttpClient): ListEventCategoriesSignature;
interface ListEventCategoriesSignature {
    /**
     * Retrieves a list of categories that are not in the `HIDDEN` state.
     * @param - Event ID.
     */
    (eventId: string): Promise<ListEventCategoriesResponse>;
}
export declare function reorderCategoryEvents(httpClient: HttpClient): ReorderCategoryEventsSignature;
interface ReorderCategoryEventsSignature {
    /**
     * Change the order of events that are assigned to the same category on the Events Widget.
     *
     *
     * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
     * @param - Category ID.
     * @param - Options to use when reordering events.
     */
    (categoryId: string, options?: ReorderCategoryEventsOptions | undefined): Promise<void>;
}
export { ActionEvent, ApplicationError, AssignEventsRequest, AssignEventsResponse, BulkActionMetadata, BulkAssignEventsAsyncOptions, BulkAssignEventsAsyncRequest, BulkAssignEventsAsyncResponse, BulkAssignEventsOptions, BulkAssignEventsRequest, BulkAssignEventsResponse, BulkCategoryResult, BulkCreateCategoryRequest, BulkCreateCategoryResponse, BulkUnassignEventsAsyncOptions, BulkUnassignEventsAsyncRequest, BulkUnassignEventsAsyncResponse, BulkUnassignEventsOptions, BulkUnassignEventsRequest, BulkUnassignEventsResponse, CategoriesQueryBuilder, CategoriesQueryResult, Category, CategoryCounts, CategoryFieldset, CreateCategoryRequest, CreateCategoryResponse, Cursors, DeleteCategoryRequest, DeleteCategoryResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, IdentificationData, IdentificationDataIdOneOf, ItemMetadata, ListEventCategoriesRequest, ListEventCategoriesResponse, MessageEnvelope, Paging, PagingMetadataV2, QueryCategoriesOptions, QueryCategoriesRequest, QueryCategoriesResponse, QueryV2, QueryV2PagingMethodOneOf, ReorderCategoryEventsOptions, ReorderCategoryEventsOptionsReferenceEventOneOf, ReorderCategoryEventsRequest, ReorderCategoryEventsRequestReferenceEventOneOf, ReorderCategoryEventsResponse, RestoreInfo, SortOrder, Sorting, State, UnassignEventsRequest, UnassignEventsResponse, UpdateCategory, UpdateCategoryRequest, UpdateCategoryResponse, WebhookIdentityType, } from './events-v1-category-categories.universal.js';
