import { RequestOptionsFactory } from '@wix/sdk-types';
/** Creates a category. */
export declare function createCategory(payload: object): RequestOptionsFactory<any>;
/** Creates multiple categories at once. */
export declare function bulkCreateCategory(payload: object): RequestOptionsFactory<any>;
/** Updates an existing category. */
export declare function updateCategory(payload: object): RequestOptionsFactory<any>;
/** Deletes a category. */
export declare function deleteCategory(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a query to retrieve a list of categories.
 *
 *
 * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
 *
 * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
 *
 * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
 *
 *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
 */
export declare function queryCategories(payload: object): RequestOptionsFactory<any>;
/** Assigns events to a single category. */
export declare function assignEvents(payload: object): RequestOptionsFactory<any>;
/** Assigns events to multiple categories at once. */
export declare function bulkAssignEvents(payload: object): RequestOptionsFactory<any>;
/**
 * Assigns events that match given filter criteria to multiple categories.
 *
 * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 */
export declare function bulkAssignEventsAsync(payload: object): RequestOptionsFactory<any>;
/** Unassigns events from a category. */
export declare function unassignEvents(payload: object): RequestOptionsFactory<any>;
/** Unassigns events from multiple categories at once. */
export declare function bulkUnassignEvents(payload: object): RequestOptionsFactory<any>;
/**
 * Removes events that match given filter criteria from multiple categories.
 *
 * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 */
export declare function bulkUnassignEventsAsync(payload: object): RequestOptionsFactory<any>;
/** Retrieves a list of categories that are not in the `HIDDEN` state. */
export declare function listEventCategories(payload: object): RequestOptionsFactory<any>;
/**
 * Change the order of events that are assigned to the same category on the Events Widget.
 *
 *
 * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
 */
export declare function reorderCategoryEvents(payload: object): RequestOptionsFactory<any>;
