import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixEventsCategoriesCategoryManagementUrl(opts) {
    const domainToMappings = {
        'events._base_domain_': [
            {
                srcPath: '',
                destPath: '',
            },
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
        ],
        'www.wixevents.com': [
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
            {
                srcPath: '/api',
                destPath: '/api',
            },
            {
                srcPath: '/viewEvent',
                destPath: '/viewEvent',
            },
            {
                srcPath: '/viewRsvpDashboard',
                destPath: '/viewRsvpDashboard',
            },
            {
                srcPath: '/viewOrderDashboard',
                destPath: '/viewOrderDashboard',
            },
            {
                srcPath: '/viewSummarySubscription',
                destPath: '/viewSummarySubscription',
            },
            {
                srcPath: '/check-in',
                destPath: '/check-in',
            },
            {
                srcPath: '/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/export',
                destPath: '/export',
            },
            {
                srcPath: '/tickets',
                destPath: '/tickets',
            },
            {
                srcPath: '/payment-redirect',
                destPath: '/payment-redirect',
            },
            {
                srcPath: '/admin',
                destPath: '/admin',
            },
            {
                srcPath: '/ticket',
                destPath: '/ticket',
            },
            {
                srcPath: '/media',
                destPath: '/media',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/wix-events-web',
                destPath: '',
            },
        ],
        'events.wixapps.net': [
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
            {
                srcPath: '/events',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
            {
                srcPath: '/_api/wix-events-web/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'apps._base_domain_': [
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
            {
                srcPath: '/events',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/wix-events-web',
                destPath: '/api',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v2/events',
                destPath: '/v2/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/events',
                destPath: '/v1/bulk/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
            {
                srcPath: '/events/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/events/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/events/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/events/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/events/v1/bulk/events',
                destPath: '/v1/bulk/events',
            },
            {
                srcPath: '/events/v1/reports',
                destPath: '/v1/reports',
            },
            {
                srcPath: '/events/v1/tickets',
                destPath: '/v1/tickets',
            },
            {
                srcPath: '/events/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/events/v1/web',
                destPath: '/v1/web',
            },
            {
                srcPath: '/events/v2/tickets',
                destPath: '/v2/tickets',
            },
            {
                srcPath: '/events/v2/events',
                destPath: '/v2/events',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/events/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/events/v1/tickets',
                destPath: '/v1/tickets',
            },
            {
                srcPath: '/events/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/events/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/events/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/events/v2/events',
                destPath: '/v2/events',
            },
            {
                srcPath: '/events/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
        ],
        'api._base_domain_': [
            {
                srcPath: '/events/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/events/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/events/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/events/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/events/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/events/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/events/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        _: [
            {
                srcPath: '/_api/wix-events-web/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/events/v2/events',
                destPath: '/v2/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/_api/wix-events-web/v2',
                destPath: '/v2',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        '*.pub.wix-code.com': [
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'editor-flow.wixapps.net': [
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/wix-events-web/v1/bulk-async/categories',
                destPath: '/v1/bulk-async/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/bulk/categories',
                destPath: '/v1/bulk/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/categories',
                destPath: '/v1/categories',
            },
            {
                srcPath: '/_api/wix-events-web/v1/events',
                destPath: '/v1/events',
            },
            {
                srcPath: '/_api/wix-events-web/v1/orders',
                destPath: '/v1/orders',
            },
            {
                srcPath: '/_api/wix-events-web/v1/tickets',
                destPath: '/v1/tickets',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_events_categories';
/** Creates a category. */
export function createCategory(payload) {
    function __createCategory({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'category.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.CreateCategory',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'category.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __createCategory;
}
/** Creates multiple categories at once. */
export function bulkCreateCategory(payload) {
    function __bulkCreateCategory({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'categories.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.BulkCreateCategory',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/bulk/categories/create',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'results.item.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __bulkCreateCategory;
}
/** Updates an existing category. */
export function updateCategory(payload) {
    function __updateCategory({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'category.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'PATCH',
            methodFqn: 'wix.events.categories.CategoryManagement.UpdateCategory',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{category.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'category.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __updateCategory;
}
/** Deletes a category. */
export function deleteCategory(payload) {
    function __deleteCategory({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'DELETE',
            methodFqn: 'wix.events.categories.CategoryManagement.DeleteCategory',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{categoryId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteCategory;
}
/**
 * Creates a query to retrieve a list of categories.
 *
 *
 * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
 *
 * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
 *
 * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
 *
 *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
 */
export function queryCategories(payload) {
    function __queryCategories({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.QueryCategories',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'categories.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __queryCategories;
}
/** Assigns events to a single category. */
export function assignEvents(payload) {
    function __assignEvents({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.AssignEvents',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{categoryId}/events',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __assignEvents;
}
/** Assigns events to multiple categories at once. */
export function bulkAssignEvents(payload) {
    function __bulkAssignEvents({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.BulkAssignEvents',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/bulk/categories/events',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'results.item.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __bulkAssignEvents;
}
/**
 * Assigns events that match given filter criteria to multiple categories.
 *
 * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 */
export function bulkAssignEventsAsync(payload) {
    function __bulkAssignEventsAsync({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.BulkAssignEventsAsync',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/bulk-async/categories/assign-events-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkAssignEventsAsync;
}
/** Unassigns events from a category. */
export function unassignEvents(payload) {
    function __unassignEvents({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'DELETE',
            methodFqn: 'wix.events.categories.CategoryManagement.UnassignEvents',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{categoryId}/events',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __unassignEvents;
}
/** Unassigns events from multiple categories at once. */
export function bulkUnassignEvents(payload) {
    function __bulkUnassignEvents({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'DELETE',
            methodFqn: 'wix.events.categories.CategoryManagement.BulkUnassignEvents',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/bulk/categories/events',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'results.item.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __bulkUnassignEvents;
}
/**
 * Removes events that match given filter criteria from multiple categories.
 *
 * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
 *
 * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
 */
export function bulkUnassignEventsAsync(payload) {
    function __bulkUnassignEventsAsync({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.BulkUnassignEventsAsync',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/bulk-async/categories/unassign-events-by-filter',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkUnassignEventsAsync;
}
/** Retrieves a list of categories that are not in the `HIDDEN` state. */
export function listEventCategories(payload) {
    function __listEventCategories({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'GET',
            methodFqn: 'wix.events.categories.CategoryManagement.ListEventCategories',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{eventId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'categories.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __listEventCategories;
}
/**
 * Change the order of events that are assigned to the same category on the Events Widget.
 *
 *
 * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
 */
export function reorderCategoryEvents(payload) {
    function __reorderCategoryEvents({ host }) {
        const metadata = {
            entityFqdn: 'wix.events.v1.category',
            method: 'POST',
            methodFqn: 'wix.events.categories.CategoryManagement.ReorderCategoryEvents',
            packageName: PACKAGE_NAME,
            url: resolveWixEventsCategoriesCategoryManagementUrl({
                protoPath: '/v1/categories/{categoryId}/reorder',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __reorderCategoryEvents;
}
//# sourceMappingURL=events-v1-category-categories.http.js.map